@@ -1,4 +1,4 @@
-#![allow(clippy::let_and_return, clippy::let_unit_value)]
+#![allow(missing_docs)]
 
 macro_rules! bench_fn {
     ($group:expr, $bench_fn:ident) => {
