@@ -273,6 +273,21 @@ fn strip(src: &Path, dst: impl AsRef<OsStr>, options: &[&str]) {
     toolize_o("strip", src, dst, options)
 }
 
+/// Create a file with compressed `.gnu_debugdata` data based on a
+/// source binary.
+fn gnu_debugdata(src: &Path, dst: impl AsRef<OsStr>) {
+    let dst = src.with_file_name(dst);
+    let convert_sh = data_dir().join("gnu_debugdata.sh");
+    println!("cargo:rerun-if-changed={}", src.display());
+    println!("cargo:rerun-if-changed={}", dst.display());
+    println!("cargo:rerun-if-changed={}", convert_sh.display());
+
+    let () = run("/bin/sh", [&convert_sh, src, &dst], identity)
+        .expect("failed to create mini debuginfo file");
+
+    let () = adjust_mtime(&dst).unwrap();
+}
+
 /// Create a DWARF package for a list of DWO files.
 #[cfg(feature = "thorin_dwp")]
 fn dwp<'p, D, P>(dwos: D, dst: &Path)
@@ -454,7 +469,7 @@ fn zip(files: &[PathBuf], dst: &Path) {
             let contents = read_file(file).unwrap();
             let path = file.strip_prefix(dst_dir).unwrap();
             let () = zip.start_file(path.to_str().unwrap(), options).unwrap();
-            let _count = zip.write(&contents).unwrap();
+            let _count = zip.write_all(&contents).unwrap();
         }
     }
 
@@ -630,6 +645,16 @@ fn prepare_test_files() {
         "libtest-so-partly-stripped.so",
         &["--keep-symbol=the_ignored_answer"],
     );
+    dwarf(&src, "libtest-so-dwarf-only.dbg");
+    let dbg = data_dir.join("libtest-so-dwarf-only.dbg");
+    objcopy(
+        &src,
+        "libtest-so-stripped-with-link.so",
+        &[
+            "--strip-all",
+            &format!("--add-gnu-debuglink={}", dbg.display()),
+        ],
+    );
 
     let src = data_dir.join("test-exe.c");
     cc(&src, "test-no-debug.bin", &["-g0", "-Wl,--build-id=none"]);
@@ -673,6 +698,9 @@ fn prepare_test_files() {
     let src = data_dir.join("test-mnt-ns.c");
     cc(&src, "test-mnt-ns.bin", &[]);
 
+    let src = data_dir.join("test-chroot-dbg-link.c");
+    cc(&src, "test-chroot-dbg-link.bin", &[]);
+
     let src = data_dir.join("test-block.c");
     let ld_script = data_dir.join("test-block-augmented.ld");
     let args = &[
@@ -740,6 +768,7 @@ fn prepare_test_files() {
             &format!("--add-gnu-debuglink={}", dbg.display()),
         ],
     );
+    gnu_debugdata(&src, "test-stable-addrs-debugdata.bin");
 
     let elf = data_dir.join("test-stable-addrs-no-dwarf.bin");
     objcopy(
@@ -919,7 +948,7 @@ fn download_multi_part(base_url: &reqwest::Url, part_count: usize, dst: &Path) {
     for part in 1..=part_count {
         let url = reqwest::Url::parse(&format!("{}.part{part}", base_url.as_str())).unwrap();
         let response = client.get(url).send().unwrap();
-        let _count = dst.write(&response.bytes().unwrap()).unwrap();
+        let _count = dst.write_all(&response.bytes().unwrap()).unwrap();
     }
 }
 
