@@ -115,6 +115,13 @@ where
             ),
         }
     }
+
+    pub fn to_owned(&self) -> ElfNSlice<'static, T> {
+        match self {
+            Self::B32(slice) => ElfNSlice::B32(Cow::Owned(slice.to_vec())),
+            Self::B64(slice) => ElfNSlice::B64(Cow::Owned(slice.to_vec())),
+        }
+    }
 }
 
 
@@ -518,9 +525,9 @@ impl Elf64_Sym {
 impl SymType {
     fn try_from_elf_type(elf_type: u8) -> Result<Self, ()> {
         match elf_type {
-            STT_NOTYPE => Ok(SymType::Undefined),
-            STT_FUNC | STT_GNU_IFUNC => Ok(SymType::Function),
-            STT_OBJECT => Ok(SymType::Variable),
+            STT_NOTYPE => Ok(Self::Undefined),
+            STT_FUNC | STT_GNU_IFUNC => Ok(Self::Function),
+            STT_OBJECT => Ok(Self::Variable),
             _ => Err(()),
         }
     }
@@ -530,7 +537,7 @@ impl TryFrom<&Elf64_Sym> for SymType {
     type Error = ();
 
     fn try_from(other: &Elf64_Sym) -> Result<Self, Self::Error> {
-        SymType::try_from_elf_type(other.type_())
+        Self::try_from_elf_type(other.type_())
     }
 }
 
@@ -538,7 +545,7 @@ impl TryFrom<&ElfN<'_, Elf64_Sym>> for SymType {
     type Error = ();
 
     fn try_from(other: &ElfN<'_, Elf64_Sym>) -> Result<Self, Self::Error> {
-        SymType::try_from_elf_type(other.type_())
+        Self::try_from_elf_type(other.type_())
     }
 }
 
@@ -724,6 +731,10 @@ mod tests {
 
         let sym = Elf32_Sym::default();
         let _sym64 = Elf64_Sym::from(&sym);
+
+        let syms = [sym];
+        let syms = ElfN_Syms::B32(Cow::Borrowed(&syms));
+        let _syms = syms.to_owned();
     }
 
     /// Exercise some accessor functions.
