@@ -1,7 +1,10 @@
 use std::borrow::Cow;
 use std::env;
 use std::env::current_exe;
+use std::ffi::CStr;
+use std::ffi::CString;
 use std::ffi::OsStr;
+use std::fs;
 use std::fs::copy;
 use std::fs::metadata;
 use std::fs::read as read_file;
@@ -56,7 +59,7 @@ use blazesym::__private::find_the_answer_fn_in_zip;
 #[cfg(linux)]
 use blazesym_dev::with_bpf_symbolization_target_addrs;
 
-use rand::Rng as _;
+use rand::RngExt as _;
 use scopeguard::defer;
 
 use tempfile::tempdir;
@@ -204,7 +207,11 @@ fn symbolize_no_permission_impl(path: &Path) {
 /// permission to open the symbolization source.
 #[cfg(linux)]
 #[fork]
-#[test]
+// We use the default `#[test]` here to not initialize `tracing`. This
+// is suspected to be the cause of occasional segfaults.
+// TODO: Once ruled out/confirmed, we should revert or fix this
+//       properly, respectively.
+#[std::prelude::v1::test]
 fn symbolize_elf_no_permission() {
     use libc::getresuid;
     use std::os::unix::fs::PermissionsExt as _;
@@ -463,6 +470,26 @@ fn symbolize_elf_stripped() {
     assert_eq!(result, Symbolized::Unknown(Reason::MissingSyms));
 }
 
+/// Make sure that we can symbolize data from a compressed
+/// `.gnu_debugdata` section.
+#[tag(other_os)]
+#[test]
+fn symbolize_elf_compressed_gnu_debugdata() {
+    let path = Path::new(&env!("CARGO_MANIFEST_DIR"))
+        .join("data")
+        .join("test-stable-addrs-debugdata.bin");
+    let src = Source::Elf(Elf::new(path));
+    let symbolizer = Symbolizer::new();
+    let result = symbolizer
+        .symbolize_single(&src, Input::VirtOffset(0x2000200))
+        .unwrap()
+        .into_sym()
+        .unwrap();
+
+    assert_eq!(result.name, "factorial");
+    assert_eq!(result.addr, 0x2000200);
+}
+
 /// Check that we can symbolize data in a non-existent ELF binary after
 /// caching it.
 #[test]
@@ -936,7 +963,10 @@ fn symbolize_rust_dwp() {
 #[test]
 fn symbolize_process() {
     let src = Source::Process(Process::new(Pid::Slf));
-    let addrs = [symbolize_process as Addr, Symbolizer::symbolize as Addr];
+    let addrs = [
+        symbolize_process as *const () as Addr,
+        Symbolizer::symbolize as *const () as Addr,
+    ];
     let symbolizer = Symbolizer::new();
     let results = symbolizer
         .symbolize(&src, Input::AbsAddr(&addrs))
@@ -981,13 +1011,46 @@ fn symbolize_process_in_mount_namespace() {
     let test_so = Path::new(&env!("CARGO_MANIFEST_DIR"))
         .join("data")
         .join("libtest-so.so");
-    let mnt_ns = Path::new(&env!("CARGO_MANIFEST_DIR"))
+    let mnt_ns_bin = Path::new(&env!("CARGO_MANIFEST_DIR"))
         .join("data")
         .join("test-mnt-ns.bin");
 
+    let mnt_dir = tempdir().unwrap();
+    let mnt_path = mnt_dir.path().to_path_buf();
+    let lib_path = mnt_path.join("lib.so");
+
     let () = RemoteProcess::default()
-        .arg(&test_so)
-        .exec(&mnt_ns, |pid, addr| {
+        .arg(&lib_path)
+        .pre_exec(move || {
+            // Create a mount namespace.
+            let rc = unsafe { libc::unshare(libc::CLONE_NEWNS) };
+            if rc != 0 {
+                return Err(io::Error::last_os_error());
+            }
+
+            // Mount a tmpfs at the temp directory.
+            let target = CString::new(mnt_path.as_os_str().as_encoded_bytes()).unwrap();
+            let rc = unsafe {
+                libc::mount(
+                    CStr::from_bytes_with_nul(b"tmpfs\0").unwrap().as_ptr(),
+                    target.as_ptr(),
+                    CStr::from_bytes_with_nul(b"tmpfs\0").unwrap().as_ptr(),
+                    0,
+                    CStr::from_bytes_with_nul(b"size=16M\0")
+                        .unwrap()
+                        .as_ptr()
+                        .cast(),
+                )
+            };
+            if rc != 0 {
+                return Err(io::Error::last_os_error());
+            }
+
+            // Copy the library.
+            let _cnt = fs::copy(&test_so, &lib_path)?;
+            Ok(())
+        })
+        .exec(&mnt_ns_bin, |pid, addr| {
             let src = Source::Process(Process::new(pid));
             let symbolizer = Symbolizer::new();
             let result = symbolizer
@@ -999,6 +1062,86 @@ fn symbolize_process_in_mount_namespace() {
         });
 }
 
+/// Check symbolization involving a debug link reference relative to a
+/// process's changed root directory.
+#[cfg(linux)]
+#[test]
+fn symbolize_process_debug_link_in_chroot() {
+    use tempfile::tempdir;
+
+    let stripped_so = Path::new(&env!("CARGO_MANIFEST_DIR"))
+        .join("data")
+        .join("libtest-so-stripped-with-link.so");
+    let debug_file = Path::new(&env!("CARGO_MANIFEST_DIR"))
+        .join("data")
+        .join("libtest-so-dwarf-only.dbg");
+    let mnt_ns_bin = Path::new(&env!("CARGO_MANIFEST_DIR"))
+        .join("data")
+        .join("test-chroot-dbg-link.bin");
+
+    let mnt_dir = tempdir().unwrap();
+    let mnt_path = mnt_dir.path().to_path_buf();
+    let lib_path = mnt_path.join("lib.so");
+
+    let () = RemoteProcess::default()
+        .arg(&mnt_path)
+        .arg(&lib_path)
+        .pre_exec(move || {
+            // Create a mount namespace.
+            let rc = unsafe { libc::unshare(libc::CLONE_NEWNS) };
+            if rc != 0 {
+                return Err(io::Error::last_os_error());
+            }
+
+            // Mount a tmpfs at the temp directory.
+            let target = CString::new(mnt_path.as_os_str().as_encoded_bytes()).unwrap();
+            let rc = unsafe {
+                libc::mount(
+                    CStr::from_bytes_with_nul(b"tmpfs\0").unwrap().as_ptr(),
+                    target.as_ptr(),
+                    CStr::from_bytes_with_nul(b"tmpfs\0").unwrap().as_ptr(),
+                    0,
+                    CStr::from_bytes_with_nul(b"size=16M\0")
+                        .unwrap()
+                        .as_ptr()
+                        .cast(),
+                )
+            };
+            if rc != 0 {
+                return Err(io::Error::last_os_error());
+            }
+
+            // Copy the stripped library.
+            let _cnt = fs::copy(&stripped_so, mnt_path.join("lib.so"))?;
+
+            // Create the debug directory structure and copy the debug file.
+            let () = fs::create_dir_all(mnt_path.join("usr/lib/debug"))?;
+            let _cnt = fs::copy(
+                &debug_file,
+                mnt_path.join("usr/lib/debug/libtest-so-dwarf-only.dbg"),
+            )?;
+            Ok(())
+        })
+        .exec(&mnt_ns_bin, |pid, addr| {
+            let src = Source::Process(Process::new(pid));
+            let symbolizer = Symbolizer::new();
+            let result = symbolizer
+                .symbolize_single(&src, Input::AbsAddr(addr))
+                .unwrap()
+                .into_sym();
+            // The address is of a static function (`private_function`) which
+            // is stripped from `.dynsym`. It can only be symbolized via DWARF
+            // debug info. The debug file only exists in the target process's
+            // mount namespace.
+            // TODO: Once mount namespace support is added for debug
+            //       link lookup, this assertion should be adjusted.
+            assert_eq!(
+                result, None,
+                "expected symbolization to fail because debug file is in different mount namespace"
+            );
+        });
+}
+
 /// Check that we can symbolize addresses from a process that has
 /// already exited, based on VMA data cached earlier.
 #[cfg(linux)]
@@ -1107,8 +1250,8 @@ fn symbolize_process_with_custom_dispatch() {
     fn test(dispatcher: impl ProcessDispatch + 'static) {
         let src = Source::Process(Process::new(Pid::Slf));
         let addrs = [
-            symbolize_process as Addr,
-            symbolize_process_with_custom_dispatch as Addr,
+            symbolize_process as *const () as Addr,
+            symbolize_process_with_custom_dispatch as *const () as Addr,
         ];
         let symbolizer = Symbolizer::builder()
             .set_process_dispatcher(dispatcher)
@@ -1146,7 +1289,10 @@ fn symbolize_own_process_vdso() {
     let src = Source::Process(Process::new(Pid::Slf));
     // Both functions are typically provided by the vDSO, though there
     // is no guarantee of that.
-    let addrs = [gettimeofday as Addr, clock_gettime as Addr];
+    let addrs = [
+        gettimeofday as *const () as Addr,
+        clock_gettime as *const () as Addr,
+    ];
     let symbolizer = Symbolizer::new();
 
     // Symbolize twice, to exercise both cache population and cache
@@ -1234,12 +1380,15 @@ fn symbolize_process_perf_map() {
 
     let script = r#"
 import ctypes
+import os
 import sys
 
 sys.activate_stack_trampoline("perf")
 
 def main():
-  open("/proc/self/fd/1", "wb").write(ctypes.c_uint64(0x0))
+  with open("/proc/self/fd/1", "wb") as stderr:
+    stderr.write(ctypes.c_uint32(os.getpid()))
+    stderr.write(ctypes.c_uint64(0x0))
   input()
   return 0
 
